@@ -1,16 +1,18 @@
-from babel import Locale
+import pytest
 import sqlalchemy as sa
 from sqlalchemy_utils.types import WeekDaysType
+from sqlalchemy_utils.types.weekdays import babel
 from sqlalchemy_utils.primitives import WeekDays
 from sqlalchemy_utils import i18n
 
 from tests import TestCase
 
 
+@pytest.mark.skipif('babel is None')
 class WeekDaysTypeTestCase(TestCase):
     def setup_method(self, method):
         TestCase.setup_method(self, method)
-        i18n.get_locale = lambda: Locale('en')
+        i18n.get_locale = lambda: babel.Locale('en')
 
     def create_models(self):
         class Schedule(self.Base):
